# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contek_viper/execution/market_signal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*contek_viper/execution/market_signal.proto\x12\x16\x63ontek_viper.execution\"\x90\x01\n\x0cMarketSignal\x12\x0e\n\x06market\x18\x01 \x01(\t\x12\x0e\n\x06signal\x18\x02 \x01(\x01\x12\x14\n\x0ctrigger_name\x18\x03 \x01(\t\x12\x18\n\x10\x61mplified_signal\x18\x04 \x01(\x01\x12\x12\n\nmultiplier\x18\x05 \x01(\x01\x12\x0b\n\x03\x63\x61p\x18\x06 \x01(\x01\x12\x0f\n\x07\x63ushion\x18\x07 \x01(\x01\x42\x1d\n\x19io.contek.viper.executionP\x01\x62\x06proto3')



_MARKETSIGNAL = DESCRIPTOR.message_types_by_name['MarketSignal']
MarketSignal = _reflection.GeneratedProtocolMessageType('MarketSignal', (_message.Message,), {
  'DESCRIPTOR' : _MARKETSIGNAL,
  '__module__' : 'contek_viper.execution.market_signal_pb2'
  # @@protoc_insertion_point(class_scope:contek_viper.execution.MarketSignal)
  })
_sym_db.RegisterMessage(MarketSignal)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031io.contek.viper.executionP\001'
  _MARKETSIGNAL._serialized_start=71
  _MARKETSIGNAL._serialized_end=215
# @@protoc_insertion_point(module_scope)
