# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contek_viper/execution/execution_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from contek_viper.execution import market_signal_pb2 as contek__viper_dot_execution_dot_market__signal__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.contek_viper/execution/execution_service.proto\x12\x16\x63ontek_viper.execution\x1a*contek_viper/execution/market_signal.proto\"|\n\x1aSubmitMarketSignalsRequest\x12;\n\rmarket_signal\x18\x01 \x03(\x0b\x32$.contek_viper.execution.MarketSignal\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x03 \x01(\t\"\x1d\n\x1bSubmitMarketSignalsResponse2\x95\x01\n\x10\x45xecutionService\x12\x80\x01\n\x13SubmitMarketSignals\x12\x32.contek_viper.execution.SubmitMarketSignalsRequest\x1a\x33.contek_viper.execution.SubmitMarketSignalsResponse\"\x00\x42\x1d\n\x19io.contek.viper.executionP\x01\x62\x06proto3')



_SUBMITMARKETSIGNALSREQUEST = DESCRIPTOR.message_types_by_name['SubmitMarketSignalsRequest']
_SUBMITMARKETSIGNALSRESPONSE = DESCRIPTOR.message_types_by_name['SubmitMarketSignalsResponse']
SubmitMarketSignalsRequest = _reflection.GeneratedProtocolMessageType('SubmitMarketSignalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITMARKETSIGNALSREQUEST,
  '__module__' : 'contek_viper.execution.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:contek_viper.execution.SubmitMarketSignalsRequest)
  })
_sym_db.RegisterMessage(SubmitMarketSignalsRequest)

SubmitMarketSignalsResponse = _reflection.GeneratedProtocolMessageType('SubmitMarketSignalsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITMARKETSIGNALSRESPONSE,
  '__module__' : 'contek_viper.execution.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:contek_viper.execution.SubmitMarketSignalsResponse)
  })
_sym_db.RegisterMessage(SubmitMarketSignalsResponse)

_EXECUTIONSERVICE = DESCRIPTOR.services_by_name['ExecutionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031io.contek.viper.executionP\001'
  _SUBMITMARKETSIGNALSREQUEST._serialized_start=118
  _SUBMITMARKETSIGNALSREQUEST._serialized_end=242
  _SUBMITMARKETSIGNALSRESPONSE._serialized_start=244
  _SUBMITMARKETSIGNALSRESPONSE._serialized_end=273
  _EXECUTIONSERVICE._serialized_start=276
  _EXECUTIONSERVICE._serialized_end=425
# @@protoc_insertion_point(module_scope)
